@@ -15,7 +15,7 @@ build = "797"
 sh = ['scribo']
 desktop_file = ['scribo.desktop']
 pixmaps = glob.glob('data/*.png')+ glob.glob('data/*.ico')
-srcs = glob.glob('src/*.py') 
+srcs = glob.glob('src/*.py')+glob.glob('src/*.qm') 
 uisrcs =  glob.glob('src/ui/*.py') 
 bugsrcs =  glob.glob('src/bugz/*.py') 
 ldmsrcs = glob.glob('src/ldm/*.py') 
