@@ -33,7 +33,7 @@ def main():
 
         from PyQt4 import QtGui
         app = QtGui.QApplication(sys.argv) # Note: we can't draw dialog box in 
-                                           #       BugReporter before gui init
+                                         #       BugReporter before gui init
 
 
         # check for another instance of application
@@ -46,7 +46,10 @@ def main():
                                       exc.to_html(),
                                       QtGui.QMessageBox.Ok)
             sys.exit()
-
+        from PyQt4 import QtCore
+        translator = QtCore.QTranslator()
+        translator.load("scribo_ru.qm")
+        app.installTranslator(translator)
         from ui.MainWindow import main_window
         from ConfigDriver import config
 
