@@ -270,7 +270,7 @@ class LivejAccount(Account, Service):
 
         param = {}
         param.update({
-                      'event': msg.text.replace('\n', '<br />\n'),
+                      'event': msg.text.replace('\n', '<br />'),
                       'subject': msg.title,
                       'props': {
                                 'taglist': msg.tags,
@@ -363,7 +363,11 @@ class LivejAccount(Account, Service):
         if 'subject' in lj_post:
             new_post.title = self._parse_string(lj_post['subject'])
 
-        new_post.text = self._parse_string(lj_post['event'])
+        #convert text in our (HTML) format (\n to <br> )
+        event = self._parse_string(lj_post['event'])
+        event = event.replace('\n', '<br>')
+        new_post.text = event
+
         new_post.date = self._parse_string(lj_post['eventtime'])
 
         if 'url' in lj_post:
@@ -619,6 +623,48 @@ class LivejAccount(Account, Service):
         return has_new
 
 
+    def _parse_friend_post(self, lj_post, new_post=None):
+        """
+        Converts answer with post from LJ into Message instance
+        """
+        if not new_post:
+            new_post = Message()
+
+        # parse result
+        #convert text in our (HTML) format (\n to <br> )
+        event = self._parse_string(lj_post['event_raw'])
+        event = event.replace('\n', '<br>')
+        new_post.text = event
+
+        new_post.title = self._parse_string(lj_post['subject_raw'])
+
+        url = lj_post['poster_userpic_url']
+        if len(url) > 0:
+            new_post.path_to_ava = self._get_avatar(url)
+        else:
+            new_post.path_to_ava = None
+
+        date = lj_post['logtime']
+        new_post.date = time.strftime("%Y-%m-%d %H:%M:%S",
+                                 time.localtime(date))
+
+        poster = self.find(LivejAccount,
+                           lj_post['postername'])
+        if not poster:
+            poster = LivejAccount()
+            poster.username = lj_post['postername']
+            poster.group = ('P' != lj_post['postertype'])
+        new_post.poster = poster
+
+        new_post.custom_id = lj_post['ditemid']
+
+        journal = self.find(LivejAccount,
+                            lj_post['journalname'])
+        journal.add_post(new_post)
+
+        return new_post
+
+
     def refresh_friends_page(self, callback):
         """
         Check for new posts in friend-page, then updating frind list and 
@@ -668,6 +714,9 @@ class LivejAccount(Account, Service):
         else:
             page = ONE_PAGE
 
+        if self in self.get_friends():
+            self.refresh_posts(callback)
+
         while True:
             param = {}
             param['itemshow'] = str(page)
@@ -678,37 +727,14 @@ class LivejAccount(Account, Service):
 
             getted = len(result)
             for i in xrange(getted):
-                msg = Message.find(custom_id=result[i]['ditemid'])
+                if self.username == result[i]['postername']:
+                    url_id = 'url LIKE "%%%s.html"' % result[i]['ditemid']
+                    msg = Message.find(where=url_id)
+                else:
+                    msg = Message.find(custom_id=result[i]['ditemid'])
+
                 if not msg:
-                    msg = Message()
-
-                    # parse result
-                    msg.text = self._parse_string(result[i]['event_raw'])
-                    msg.title = self._parse_string(result[i]['subject_raw'])
-
-                    url = result[i]['poster_userpic_url']
-                    if len(url) > 0:
-                        msg.path_to_ava = self._get_avatar(url)
-                    else:
-                        msg.path_to_ava = None
-
-                    date = result[i]['logtime']
-                    msg.date = time.strftime("%Y-%m-%d %H:%M:%S",
-                                             time.localtime(date))
-
-                    poster = self.find(LivejAccount,
-                                       result[i]['postername'])
-                    if not poster:
-                        poster = LivejAccount()
-                        poster.username = result[i]['postername']
-                        poster.group = ('P' != result[i]['postertype'])
-                    msg.poster = poster
-
-                    msg.custom_id = result[i]['ditemid']
-
-                    journal = self.find(LivejAccount,
-                                        result[i]['journalname'])
-                    journal.add_post(msg)
+                    self._parse_friend_post(result[i])
 
                 else:
                     # end loop if we start to parse old messages and we have no
