@@ -166,7 +166,7 @@ class AddPostWindow(ToolbarWindow):
         if self.tags:
             mes.tags = unicode(self.tags)
 
-        from RepeatPost import *
+        from ui.RepeatPost import *
         rep_post = RepeatPost(main_window, mes)
         main_window.push_window(rep_post)
 
@@ -222,8 +222,8 @@ class AddPostWindow(ToolbarWindow):
         msg = QtGui.QMessageBox()
         uri_edit = QtGui.QLineEdit(msg)
         uri_edit.setText("http://")
-        msg.setWindowTitle("Add picture")
-        title_label = QtGui.QLabel("Type link on the picture in web", msg)
+        msg.setWindowTitle(self.tr("Add picture"))
+        title_label = QtGui.QLabel(self.tr("Type link on the picture in web"), msg)
         msg.layout().addWidget(title_label, 0, 0, 1, 3, QtCore.Qt.AlignLeft)
         msg.layout().addWidget(uri_edit, 1, 0, 1, 3, QtCore.Qt.AlignLeft)
         link_button = msg.addButton(self.tr("Add"),
@@ -249,12 +249,12 @@ class AddPostWindow(ToolbarWindow):
 
 
         msg = QtGui.QMessageBox()
-        msg.setWindowTitle("Add link")
+        msg.setWindowTitle(self.tr("Add link"))
         uri_edit = QtGui.QLineEdit(msg)
         title_edit = QtGui.QLineEdit(msg)
         title_edit.setFocus()
         uri_edit.setText("http://")
-        title_label = QtGui.QLabel("Type link and address", msg)
+        title_label = QtGui.QLabel(self.tr("Type link and address"), msg)
         msg.layout().addWidget(title_label, 0, 0, 1, 3, QtCore.Qt.AlignLeft)
         msg.layout().addWidget(title_edit, 1, 0, 1, 2, QtCore.Qt.AlignLeft)
         msg.layout().addWidget(uri_edit, 2, 0, 1, 3, QtCore.Qt.AlignLeft)
@@ -291,7 +291,7 @@ class AddPostWindow(ToolbarWindow):
         but_box.setOrientation(QtCore.Qt.Horizontal)
         but_box2.setOrientation(QtCore.Qt.Horizontal)
 
-        self.dial.setWindowTitle("Add html tags")
+        self.dial.setWindowTitle(self.tr("Add html tags"))
         self.dial.setOrientation(QtCore.Qt.Horizontal)
         self.bold_button = but_box.addButton(self.tr("Bold"),
                                      QtGui.QDialogButtonBox.ActionRole)
@@ -360,7 +360,7 @@ class AddPostWindow(ToolbarWindow):
             #color_edit.setText(self.text_edit.toPlainText())
 
             msg2 = QtGui.QMessageBox()
-            title = QtGui.QLabel("Color text", msg2)
+            title = QtGui.QLabel(self.tr("Color text"), msg2)
             msg2.layout().addWidget(title, 0, 0, 1, 3, QtCore.Qt.AlignLeft)
             msg2.layout().addWidget(color_edit, 1, 0, 1, 3, QtCore.Qt.AlignLeft)
 
@@ -393,7 +393,7 @@ class AddPostWindow(ToolbarWindow):
         """
 
         msg = QtGui.QMessageBox()
-        msg.setWindowTitle("Add option")
+        msg.setWindowTitle(self.tr("Add option"))
         tag_edit = QtGui.QTextEdit(msg)
         tags = None
         if self.msg:
@@ -401,7 +401,7 @@ class AddPostWindow(ToolbarWindow):
         if not tags:
             tags = ""
         tag_edit.setText(tags)
-        title_label = QtGui.QLabel("Type your tags")
+        title_label = QtGui.QLabel(self.tr("Comma separated tags"))
         msg.layout().addWidget(title_label, 0, 0, 1, 3, QtCore.Qt.AlignLeft)
         msg.layout().addWidget(tag_edit, 1, 0, 1, 3, QtCore.Qt.AlignLeft)
         link_button = msg.addButton(self.tr("Add"),
