@@ -90,19 +90,19 @@ class HomePage(QtGui.QWidget):
 
         def_acc = main_prof.def_account
 
-        info = "<h2>Personal info:</h2><br>"
+        info = self.tr("<h2>Personal info:</h2><br>")
         if def_acc.nick:
-            info = info + "<div>Nick: <b>"\
-            + unicode(def_acc.nick) + "</b></div><br>"
+            info = info + self.tr("<div>Nick: <b>")\
+            + QtCore.QString(unicode(def_acc.nick)) + self.tr("</b></div><br>")
         if def_acc.date_of_birth:
-            info = info + "<div>Birthday: <b>"\
-            + unicode(def_acc.date_of_birth) + "</b></div><br>"
+            info = info + self.tr("<div>Birthday: <b>")\
+            + QtCore.QString(unicode(def_acc.date_of_birth)) + self.tr("</b></div><br>")
         if def_acc.city:
-            info = info + "<div>City: <b>"\
-            + unicode(def_acc.city) + "</b></div>"
+            info = info + self.tr("<div>City: <b>")\
+            + QtCore.QString(unicode(def_acc.city)) + self.tr("</b></div>")
         if def_acc.get_name():
-            info = info + "<div>From service: <b>"\
-            + unicode(def_acc.get_name()) + "<b><br></div><br>"
+            info = info + self.tr("<div>From service: <b>")\
+            + QtCore.QString(unicode(def_acc.get_name())) + self.tr("<b><br></div><br>")
             return info
 
     def reload_list(self, number):
@@ -138,7 +138,7 @@ class HomePage(QtGui.QWidget):
         self.info_label = QtGui.QLabel(self.fill_user_info(def_acc), self)
         self.info_label.setAlignment(QtCore.Qt.AlignLeft)
 
-        self.image_label = QtGui.QLabel("Photo", self)
+        self.image_label = QtGui.QLabel(self.tr("Photo"), self)
         self.image_label.setAlignment(QtCore.Qt.AlignCenter)
 
         self.acc_combo_box = self.create_list_acc(def_acc)
