@@ -58,10 +58,11 @@ class ListMyPosts(ToolbarWindow):
             c = config.get_bool('UI', 'warning_press_refresh')
             if not c:
                 msg = QtGui.QMessageBox()
-                show_button = QtGui.QCheckBox("Don't show this message again", msg)
-                title_label = QtGui.QLabel("Press refresh button for getting posts from services", msg)
-                msg.layout().addWidget(title_label, 0, 0, 1, 3, QtCore.Qt.AlignLeft)
-                msg.layout().addWidget(show_button, 1, 0, 1, 2, QtCore.Qt.AlignLeft)
+                msg.setWindowTitle(self.tr("Refresh message"))
+                show_button = QtGui.QCheckBox(self.tr("Don't show this message again"), msg)
+                title_label = QtGui.QLabel(self.tr("Press \"Refresh\" to update post"), msg)
+                msg.layout().addWidget(title_label, 0, 0)
+                msg.layout().addWidget(show_button, 1, 0)
                 cancel_button = msg.addButton(QtGui.QMessageBox.Close)
                 msg.exec_()
 
@@ -73,10 +74,12 @@ class ListMyPosts(ToolbarWindow):
 
         for mes in self.list:
             date = unicode(mes.date)
-            title = unicode(mes.title)
             if not mes.title:
-                title = "no subject"
-            text = unicode(date + "  " + title)
+                title = unicode(self.tr("no subject"))
+            else:
+                title = unicode(mes.title)
+            text = date + "  " + title
+
             #if not mes.read:
                 #text =text + "  <font color=\"green\">  NEW!!! </font>"
             author = mes.poster
@@ -94,7 +97,7 @@ class ListMyPosts(ToolbarWindow):
             del text
             del title
             del date
-        self.connect(list_widget, QtCore.SIGNAL("itemActivated(QListWidgetItem*)"),
+        self.connect(list_widget, QtCore.SIGNAL("itemDoubleClicked(QListWidgetItem*)"),
                      self.view_message)
         return list_widget
 
@@ -146,7 +149,7 @@ class ListMyPosts(ToolbarWindow):
         @return       
         """
         ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                               self.tr("Do you really want delete post?"),
+                               self.tr("Do you really want to delete post?"),
                                QtGui.QMessageBox.Yes,
                                QtGui.QMessageBox.No)
         if (ret == QtGui.QMessageBox.No):
@@ -167,7 +170,7 @@ class ListMyPosts(ToolbarWindow):
 
         else:
             QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                               self.tr("Please, choose deleting messages!"),
+                               self.tr("Please, choose messages to delete!"),
                                QtGui.QMessageBox.Yes)
 
 
@@ -179,8 +182,9 @@ class ListMyPosts(ToolbarWindow):
         @param          
         @return
         """
-        self.progress = QtGui.QProgressDialog("Operation in progress.",
-                                              "Cancel", 0, 10, self)
+        self.progress = QtGui.QProgressDialog(self.tr("Operation is in progress."),
+                                              self.tr("Cancel"), 0, 10, self)
+        self.progress.setWindowTitle(self.tr("Receiving data..."))
         self.progress.setWindowModality(QtCore.Qt.WindowModal)
         self.value_progress = 1
         self.progress.setValue(self.value_progress)
