@@ -50,7 +50,7 @@ class MainWindow(QtGui.QMainWindow):
         self.manage_act = QtGui.QAction(self.tr("&Manage profile"), self)
 
         if start:
-            QtGui.QMessageBox.critical(self, "Scribo", str(start))
+            QtGui.QMessageBox.critical(self, self.tr("Scribo"), str(start))
             self.close()
             sys.exit()
         else:
@@ -91,8 +91,8 @@ class MainWindow(QtGui.QMainWindow):
         from About import __version__ as ver
         #ver = 
         QtGui.QMessageBox.about(self, self.tr("About Scribo"),
-                                self.tr("A cross-blog client"\
-                                        " for maemo platform.\n Version: " + ver))
+                                self.tr("A mobile multiblog client."\
+                                        " \n Version: " + ver))
     def show_warning(self, exc):
         """  
         error message
@@ -178,6 +178,7 @@ class MainWindow(QtGui.QMainWindow):
         @param
         @return
         """
+        print "back"
         widg = self.stack_widg.currentWidget()
         self.stack_widg.removeWidget(widg)
         widg.deleteLater()
@@ -189,7 +190,7 @@ class MainWindow(QtGui.QMainWindow):
         @param
         @return
         """
-
+        print "go home"
         count = self.stack_widg.count()
 
         for _ in xrange(count):
