@@ -37,7 +37,7 @@ class RepeatPost(ToolbarWindow):
         self.mes = msg
         self.tree_view = self.tree_view_acc()
         super(RepeatPost, self).create_actions()
-        title = QtGui.QLabel("Please, choose accounts and groups for sending this post", self)
+        title = QtGui.QLabel(self.tr("Please, choose accounts and groups for sending the post"), self)
         title.setAlignment(QtCore.Qt.AlignLeft)
         toolbar = self.create_toolbar()
         self.vbox = QtGui.QVBoxLayout()
@@ -63,8 +63,8 @@ class RepeatPost(ToolbarWindow):
 
     def tree_view_acc(self):
         tree_widget = QtGui.QTreeWidget()
-        header = QtCore.QStringList("Service")
-        header.append("Logins")
+        header = QtCore.QStringList(self.tr("Service"))
+        header.append(self.tr("Login"))
         tree_widget.setHeaderLabels(header)
         tree_widget.setColumnCount(2)
         tree_widget.setSelectionMode(QtGui.QAbstractItemView.MultiSelection)
@@ -89,7 +89,7 @@ class RepeatPost(ToolbarWindow):
 
             child_login = QtGui.QTreeWidgetItem(login)
 
-            child_login.setFlags(child_login.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsSelectable)
+            child_login.setFlags(child_login.flags() | QtCore.Qt.ItemIsUserCheckable|QtCore.Qt.ItemIsEnabled)
             child_login.setText(1, acc.username)
 
             child_login.setData(1, QtCore.Qt.CheckStateRole, QtCore.QVariant(QtCore.Qt.Unchecked))
@@ -119,13 +119,14 @@ class RepeatPost(ToolbarWindow):
         return tree_widget
 
     def click_item(self, item, column):
-        select = item.data(1, QtCore.Qt.CheckStateRole).toString().toInt()[0]
-        if select == QtCore.Qt.Unchecked:
-            item.setData(1, QtCore.Qt.CheckStateRole,
-                                     QtCore.QVariant(QtCore.Qt.Checked))
-        else:
-            item.setData(1, QtCore.Qt.CheckStateRole,
-                                     QtCore.QVariant(QtCore.Qt.Unchecked))
+        if column <> 1:
+            select = item.data(1, QtCore.Qt.CheckStateRole).toString().toInt()[0]
+            if select == QtCore.Qt.Unchecked:
+                item.setData(1, QtCore.Qt.CheckStateRole,
+                                         QtCore.QVariant(QtCore.Qt.Checked))
+            else:
+                item.setData(1, QtCore.Qt.CheckStateRole,
+                                         QtCore.QVariant(QtCore.Qt.Unchecked))
 
     def send_selected(self):
         login_items = self.tree_view.selectedItems()
@@ -139,7 +140,7 @@ class RepeatPost(ToolbarWindow):
                 if not acc:
                     if len(login_items) == 1:
                         QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                                                self.tr("Please, choose subitem for sending "),
+                                                self.tr("Please, choose subitem for sending"),
                                                 QtGui.QMessageBox.Yes)
                         return
                     continue
@@ -160,13 +161,13 @@ class RepeatPost(ToolbarWindow):
                 msg_copy.del_msg_tree()
         else:
             QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                                          self.tr("Please, choose account or group for sending "),
+                                          self.tr("Please, choose accounts or groups for sending"),
                                           QtGui.QMessageBox.Yes)
 
 
         if flag_send:
             ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                                                self.tr("Post is sent"),
+                                                self.tr("Post was sent"),
                                                 QtGui.QMessageBox.Yes)
         main_window.home_window()
 
