@@ -98,7 +98,7 @@ class StartPage(QtGui.QWidget):
 
         if (self.login_edit.text() == "") or (self.pasw_edit.text() == ""):
             QtGui.QMessageBox.information(self, self.tr("Scribo"),
-                               self.tr("Please, fill all  lines!"),
+                               self.tr("Please, fill all fields!"),
                                QtGui.QMessageBox.Yes)
             return
 
