@@ -113,9 +113,9 @@ class MyModel(QtCore.QAbstractItemModel):
         """
         QtCore.QAbstractItemModel.__init__(self, parent)
         rootData = []
-        rootData.append(QtCore.QVariant("Author"))
-        rootData.append(QtCore.QVariant("Date"))
-        rootData.append(QtCore.QVariant("Title"))
+        rootData.append(QtCore.QVariant(self.tr("Author")))
+        rootData.append(QtCore.QVariant(self.tr("Date")))
+        rootData.append(QtCore.QVariant(self.tr("Title")))
         self.rootItem = TreeItem(rootData)
         self.setupModelData(msg, self.rootItem)
 
