@@ -84,7 +84,7 @@ class ViewMessage(ToolbarWindow):
             author = ""
 
         if not title:
-            title = "no subject"
+            title = self.tr("no subject")
         if not tags:
             tags = ""
         if not text:
@@ -103,27 +103,32 @@ class ViewMessage(ToolbarWindow):
         title = self.text_escape(title)
         tags = self.text_escape(tags)
         text = self.text_br(text)
+        css = "<style type=\"text/css\"> .scrib_stl {font: 14pt sans-serif;} </style>"
+
         """
         #version with comment
         self.view_mes_widget.setHtml("<head><meta http-equiv=\"Content-Type\" \
-                    content=\"text/html; charset=utf-8\" /> \
-                    </head> <h3><a href = \"scribo://parent\">\
-                    Parrent:</a></h3>" + parent_text +
-                    "<h3><font color=\"green\">\
-                    Comment:</font> </h3><b>Title: </b>" + title +
-                    "<br/> <b> Author: </b>" + author +
-                    "<br/><b> Date: </b>" + date + "<br/><b> Tags: </b>"
-                    + tags + "<br/>" "<b> Text:\
-                    </b><br />" + text + "<br/>")
+                    content=\"text/html; charset=utf-8\" /> "
+                    + str(css) + "</head><body><h3><a href = \"scribo://parent\">"+
+                    self.tr("Parrent:</a></h3>") + parent_text +
+                    "<h3><font color=\"green\">"+
+                    self.tr("Comment:</font> </h3><b>Title: </b>") + title +
+                    self.tr("<br/> <b> Author: </b>") + author +
+                    self.tr("<br/><b> Date: </b>") + date + self.tr("<br/><b> Tags: </b>")
+                    + tags + self.tr("<br/>" "<b> Text:\
+                    </b><br />") + text + "<br/>")
         """
-        self.view_mes_widget.setHtml("<head><meta http-equiv=\"Content-Type\" \
-                    content=\"text/html; charset=utf-8\" /> \
-                    </head><h3><font color=\"green\">\
-                    Post:</font> </h3><b>Title: </b>" + title +
-                    "<br/> <b> Author: </b>" + author +
-                    "<br/><b> Date: </b>" + date + "<br/><b> Tags: </b>"
-                    + tags + "<br/>" "<b> Text:\
-                    </b><br />" + text + "<br/>")
+        self.view_mes_widget.setHtml(QtCore.QString("<head><meta http-equiv=\"Content-Type\" \
+                    content=\"text/html; charset=utf-8\" /> ")
+                    + QtCore.QString(css) +
+                    QtCore.QString("</head><body><div class=\"scribo_stl\">\
+                    <h3><font color=\"green\">") +
+                    self.tr("Post:</font> </h3><b>Title: </b>") + QtCore.QString(title) +
+                    self.tr("<br/> <b> Author: </b>") + QtCore.QString(author) +
+                    self.tr("<br/><b> Date: </b>") + QtCore.QString(date)
+                    + self.tr("<br/><b> Tags: </b>")
+                    + QtCore.QString(tags) + self.tr("<br/>" "<b> Text:\
+                    </b><br /></div>") + QtCore.QString(text) + "<br/></body>")
 
         del(title)
         del(text)
@@ -191,13 +196,13 @@ class ViewMessage(ToolbarWindow):
         self.up_act = QtGui.QAction(self.tr("&Previous"), self)
         #self.up_act.setStatusTip(self.tr("Previous message"))
         self.up_act.setIcon(QtGui.QIcon("../data/prev.png"))
-        self.connect(self.up_act, QtCore.SIGNAL("activated()"),
+        self.connect(self.up_act, QtCore.SIGNAL("triggered()"),
                      self.view_prev_message)
 
         self.down_act = QtGui.QAction(self.tr("&Next"), self)
         #self.down_act.setStatusTip(self.tr("Next message"))
         self.down_act.setIcon(QtGui.QIcon("../data/next.png"))
-        self.connect(self.down_act, QtCore.SIGNAL("activated()"),
+        self.connect(self.down_act, QtCore.SIGNAL("triggered()"),
                      self.view_next_message)
         #don't realized
         """
@@ -210,13 +215,13 @@ class ViewMessage(ToolbarWindow):
         self.edit_act = QtGui.QAction(self.tr("&Edit"), self)
         #self.edit_act.setStatusTip(self.tr("Edit"))
         self.edit_act.setIcon(QtGui.QIcon("../data/add_post.png"))
-        self.connect(self.edit_act, QtCore.SIGNAL("activated()"),
+        self.connect(self.edit_act, QtCore.SIGNAL("triggered()"),
                      self.edit_post)
 
         self.tree_act = QtGui.QAction(self.tr("&Tree comments"), self)
         #self.tree_act.setStatusTip(self.tr("Tree of comments"))
         self.tree_act.setIcon(QtGui.QIcon("../data/tree.png"))
-        self.connect(self.tree_act, QtCore.SIGNAL("activated()"),
+        self.connect(self.tree_act, QtCore.SIGNAL("triggered()"),
                      self.tree_comments)
 
         super(ViewMessage, self).create_actions()
@@ -227,7 +232,7 @@ class ViewMessage(ToolbarWindow):
         @param
         @return                                              
         """
-
+        print "view prev"
         key = self.list.index(self.msg)
         if key <= 1:
             self.up_act.setDisabled(True)
@@ -247,7 +252,7 @@ class ViewMessage(ToolbarWindow):
         @param
         @return                                            
         """
-
+        print "view next"
         key = self.list.index(self.msg)
         if key >= len(self.list) - 2:
             self.down_act.setDisabled(True)
@@ -274,6 +279,7 @@ class ViewMessage(ToolbarWindow):
         @param
         @return                                          
         """
+        print "edit_post"
         edit_widg = AddPostWindow(parent=main_window, msg=self.msg)
         main_window.push_window(edit_widg)
 
